@@ -10,5 +10,7 @@ from ..text import to_filename
 
 class TestText(unittest.TestCase):
     def test_to_filename(self):
-        self.assertEqual(to_filename("Seeds of Dreams Institute", for_web=True,
-            maxlength=16), 'seeds-of-dreams')
+        self.assertEqual(
+            to_filename("Seeds of Dreams Institute", for_web=True,
+                        maxlength=16),
+            'seeds-of-dreams')
