@@ -35,17 +35,21 @@ class TestDepsRegistry(unittest.TestCase):
 class TestPageDeps(unittest.TestCase):
     def setUp(self):
         deps = WebDeps()
-        deps.lib('jquery.ui', url='/static/lib/jquery-ui-1.8.16.min.js',
+        deps.lib(
+            'jquery.ui', url='/static/lib/jquery-ui-1.8.16.min.js',
             deps='jquery')
         deps.lib('jquery', url="/static/lib/jquery-1.7.1.min.js")
-        deps.lib('deform', url="/static/lib/deform.js",
+        deps.lib(
+            'deform', url="/static/lib/deform.js",
             deps='jquery, jquery.ui')
         deps.css('jquery', url='http://jquery.css')
         deps.css('deform', url='http://deform.css', deps='jquery.ui')
         deps.css('jquery.ui', url='http://jquery.ui.css', deps='jquery')
-        deps.package('jquery.ui', libs='jquery.ui',
+        deps.package(
+            'jquery.ui', libs='jquery.ui',
             css='jquery.ui', script='alert("JQuery UI spam!");')
-        deps.package('deform', deps='jquery.ui', libs='deform',
+        deps.package(
+            'deform', deps='jquery.ui', libs='deform',
             css='deform', script='alert("Deform spam!");')
         self.PageDeps = deps.close()
 
@@ -84,14 +88,15 @@ class TestPageDeps(unittest.TestCase):
         self.assertEqual(deps.script.tags, ALERT_OUT)
         self.assertEqual(deps.top_output, CSS_OUT)
         self.assertEqual(deps.bottom_output, SCRIPTS_OUT + '\n' + ALERT_OUT)
-        self.assertEqual(str(deps),
-            '\n'.join([CSS_OUT, SCRIPTS_OUT, ALERT_OUT]))
+        self.assertEqual(str(deps), '\n'.join([
+            CSS_OUT, SCRIPTS_OUT, ALERT_OUT]))
 
     def test_request3(self):
         deps = self.PageDeps()
         deps.lib('deform, jquery')
         deps.lib('jquery')
-        self.assertEqual(deps.lib.urls, ['/static/lib/jquery-1.7.1.min.js',
+        self.assertEqual(deps.lib.urls, [
+            '/static/lib/jquery-1.7.1.min.js',
             '/static/lib/jquery-ui-1.8.16.min.js', "/static/lib/deform.js"])
 
     def test_package1(self):
